==> ejc-settlementmanage-impl-3.0.0-20230323.014022-192-sources.jar: com/ejianc/business/settlementmanage/vo/DesignSettlementDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计类结算单子表-设计工程量验收、核算清单
 * 
 * @author generator
 * 
 */
public class DesignSettlementDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表关联键
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String sort; // 序号
    private java.lang.String projectCharacteristics; // 项目特征
    private java.lang.String measuringUnit; // 计量单位
    private java.math.BigDecimal declareCompleteNum; // 完成量(申报)
    private java.math.BigDecimal declareExtaxAddition; // 除税单价(申报)
    private java.math.BigDecimal declareIntaxAddition; // 含税单价(申报)
    private java.math.BigDecimal declareExtaxAmount; // 除税合价(申报)
    private java.math.BigDecimal declareIntaxAmount; // 含税合价(申报)
    private java.math.BigDecimal auditCompleteNum; // 完成量(审核)
    private java.math.BigDecimal auditExtaxAddition; // 除税单价(审核)
    private java.math.BigDecimal auditIntaxAddition; // 含税单价(审核)
    private java.math.BigDecimal auditExtaxAmount; // 除税合价(审核)
    private java.math.BigDecimal auditIntaxAmount; // 含税合价(审核)
    private java.lang.String categorys; // 类别
    private java.lang.String remarks; // 备注
    private java.lang.String errorMessage; // 备注
    private java.math.BigDecimal cumExtaxPrice; // 累计除税金额
    private java.math.BigDecimal cumIntaxPrice; // 累计含税金额
    private java.math.BigDecimal curExtaxPrice; // 本期除税金额
    private java.math.BigDecimal curIntaxPrice; // 本期含税金额
    private java.math.BigDecimal pastQuantity; // 往期数量
    private String isEditState; // 是否可以编辑标识
    private java.math.BigDecimal cumQuantity; // 累计数量

    /**
     * 主表关联键
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表关联键
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 项目特征
     */
    public java.lang.String getProjectCharacteristics() {
        return projectCharacteristics;
    }

    /**
     * 项目特征
     */
    public void setProjectCharacteristics(java.lang.String projectCharacteristics) {
        this.projectCharacteristics = projectCharacteristics;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 完成量(申报)
     */
    public java.math.BigDecimal getDeclareCompleteNum() {
        return declareCompleteNum;
    }

    /**
     * 完成量(申报)
     */
    public void setDeclareCompleteNum(java.math.BigDecimal declareCompleteNum) {
        this.declareCompleteNum = declareCompleteNum;
    }
    /**
     * 除税单价(申报)
     */
    public java.math.BigDecimal getDeclareExtaxAddition() {
        return declareExtaxAddition;
    }

    /**
     * 除税单价(申报)
     */
    public void setDeclareExtaxAddition(java.math.BigDecimal declareExtaxAddition) {
        this.declareExtaxAddition = declareExtaxAddition;
    }
    /**
     * 含税单价(申报)
     */
    public java.math.BigDecimal getDeclareIntaxAddition() {
        return declareIntaxAddition;
    }

    /**
     * 含税单价(申报)
     */
    public void setDeclareIntaxAddition(java.math.BigDecimal declareIntaxAddition) {
        this.declareIntaxAddition = declareIntaxAddition;
    }
    /**
     * 除税合价(申报)
     */
    public java.math.BigDecimal getDeclareExtaxAmount() {
        return declareExtaxAmount;
    }

    /**
     * 除税合价(申报)
     */
    public void setDeclareExtaxAmount(java.math.BigDecimal declareExtaxAmount) {
        this.declareExtaxAmount = declareExtaxAmount;
    }
    /**
     * 含税合价(申报)
     */
    public java.math.BigDecimal getDeclareIntaxAmount() {
        return declareIntaxAmount;
    }

    /**
     * 含税合价(申报)
     */
    public void setDeclareIntaxAmount(java.math.BigDecimal declareIntaxAmount) {
        this.declareIntaxAmount = declareIntaxAmount;
    }
    /**
     * 完成量(审核)
     */
    public java.math.BigDecimal getAuditCompleteNum() {
        return auditCompleteNum;
    }

    /**
     * 完成量(审核)
     */
    public void setAuditCompleteNum(java.math.BigDecimal auditCompleteNum) {
        this.auditCompleteNum = auditCompleteNum;
    }
    /**
     * 除税单价(审核)
     */
    public java.math.BigDecimal getAuditExtaxAddition() {
        return auditExtaxAddition;
    }

    /**
     * 除税单价(审核)
     */
    public void setAuditExtaxAddition(java.math.BigDecimal auditExtaxAddition) {
        this.auditExtaxAddition = auditExtaxAddition;
    }
    /**
     * 含税单价(审核)
     */
    public java.math.BigDecimal getAuditIntaxAddition() {
        return auditIntaxAddition;
    }

    /**
     * 含税单价(审核)
     */
    public void setAuditIntaxAddition(java.math.BigDecimal auditIntaxAddition) {
        this.auditIntaxAddition = auditIntaxAddition;
    }
    /**
     * 除税合价(审核)
     */
    public java.math.BigDecimal getAuditExtaxAmount() {
        return auditExtaxAmount;
    }

    /**
     * 除税合价(审核)
     */
    public void setAuditExtaxAmount(java.math.BigDecimal auditExtaxAmount) {
        this.auditExtaxAmount = auditExtaxAmount;
    }
    /**
     * 含税合价(审核)
     */
    public java.math.BigDecimal getAuditIntaxAmount() {
        return auditIntaxAmount;
    }

    /**
     * 含税合价(审核)
     */
    public void setAuditIntaxAmount(java.math.BigDecimal auditIntaxAmount) {
        this.auditIntaxAmount = auditIntaxAmount;
    }
    /**
     * 类别
     */
    public java.lang.String getCategorys() {
        return categorys;
    }

    /**
     * 类别
     */
    public void setCategorys(java.lang.String categorys) {
        this.categorys = categorys;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public BigDecimal getCumExtaxPrice() {
        return cumExtaxPrice;
    }

    public void setCumExtaxPrice(BigDecimal cumExtaxPrice) {
        this.cumExtaxPrice = cumExtaxPrice;
    }

    public BigDecimal getCumIntaxPrice() {
        return cumIntaxPrice;
    }

    public void setCumIntaxPrice(BigDecimal cumIntaxPrice) {
        this.cumIntaxPrice = cumIntaxPrice;
    }

    public BigDecimal getCurExtaxPrice() {
        return curExtaxPrice;
    }

    public void setCurExtaxPrice(BigDecimal curExtaxPrice) {
        this.curExtaxPrice = curExtaxPrice;
    }

    public BigDecimal getCurIntaxPrice() {
        return curIntaxPrice;
    }

    public void setCurIntaxPrice(BigDecimal curIntaxPrice) {
        this.curIntaxPrice = curIntaxPrice;
    }

    public BigDecimal getPastQuantity() {
        return pastQuantity;
    }

    public void setPastQuantity(BigDecimal pastQuantity) {
        this.pastQuantity = pastQuantity;
    }

    public String getIsEditState() {
        return isEditState;
    }

    public void setIsEditState(String isEditState) {
        this.isEditState = isEditState;
    }

    public BigDecimal getCumQuantity() {
        return cumQuantity;
    }

    public void setCumQuantity(BigDecimal cumQuantity) {
        this.cumQuantity = cumQuantity;
    }
}

==> ejc-settlementmanage-impl-3.0.0-20230525.080453-250-sources.jar: com/ejianc/business/settlementmanage/vo/DesignSettlementDetailVO.java <==
package com.ejianc.business.settlementmanage.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 设计类结算单子表-设计工程量验收、核算清单
 * 
 * @author generator
 * 
 */
public class DesignSettlementDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表关联键
    private java.lang.String billCode; // 单据编号
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id
    private java.lang.String sort; // 序号
    private java.lang.String projectCharacteristics; // 项目特征
    private java.lang.String measuringUnit; // 计量单位
    private java.math.BigDecimal declareCompleteNum; // 完成量(申报)
    private java.math.BigDecimal declareExtaxAddition; // 除税单价(申报)
    private java.math.BigDecimal declareIntaxAddition; // 含税单价(申报)
    private java.math.BigDecimal declareExtaxAmount; // 除税合价(申报)
    private java.math.BigDecimal declareIntaxAmount; // 含税合价(申报)
    private java.math.BigDecimal auditCompleteNum; // 完成量(审核)
    private java.math.BigDecimal auditExtaxAddition; // 除税单价(审核)
    private java.math.BigDecimal auditIntaxAddition; // 含税单价(审核)
    private java.math.BigDecimal auditExtaxAmount; // 除税合价(审核)
    private java.math.BigDecimal auditIntaxAmount; // 含税合价(审核)
    private java.lang.String categorys; // 类别
    private java.lang.String remarks; // 备注
    private java.lang.String errorMessage; // 备注
    private java.math.BigDecimal cumExtaxPrice; // 累计除税金额
    private java.math.BigDecimal cumIntaxPrice; // 累计含税金额
    private java.math.BigDecimal curExtaxPrice; // 本期除税金额
    private java.math.BigDecimal curIntaxPrice; // 本期含税金额
    private java.math.BigDecimal pastQuantity; // 往期数量
    private String isEditState; // 是否可以编辑标识
    private java.math.BigDecimal cumQuantity; // 累计数量
    private BigDecimal exTaxUnitLastAudit;
    private BigDecimal inTaxUnitLastAudit;

    public BigDecimal getInTaxUnitLastAudit() {
        return inTaxUnitLastAudit;
    }

    public void setInTaxUnitLastAudit(BigDecimal inTaxUnitLastAudit) {
        this.inTaxUnitLastAudit = inTaxUnitLastAudit;
    }

    public BigDecimal getExTaxUnitLastAudit() {
        return exTaxUnitLastAudit;
    }

    public void setExTaxUnitLastAudit(BigDecimal exTaxUnitLastAudit) {
        this.exTaxUnitLastAudit = exTaxUnitLastAudit;
    }

    /**
     * 主表关联键
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表关联键
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 合同id
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    /**
     * 项目特征
     */
    public java.lang.String getProjectCharacteristics() {
        return projectCharacteristics;
    }

    /**
     * 项目特征
     */
    public void setProjectCharacteristics(java.lang.String projectCharacteristics) {
        this.projectCharacteristics = projectCharacteristics;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 完成量(申报)
     */
    public java.math.BigDecimal getDeclareCompleteNum() {
        return declareCompleteNum;
    }

    /**
     * 完成量(申报)
     */
    public void setDeclareCompleteNum(java.math.BigDecimal declareCompleteNum) {
        this.declareCompleteNum = declareCompleteNum;
    }
    /**
     * 除税单价(申报)
     */
    public java.math.BigDecimal getDeclareExtaxAddition() {
        return declareExtaxAddition;
    }

    /**
     * 除税单价(申报)
     */
    public void setDeclareExtaxAddition(java.math.BigDecimal declareExtaxAddition) {
        this.declareExtaxAddition = declareExtaxAddition;
    }
    /**
     * 含税单价(申报)
     */
    public java.math.BigDecimal getDeclareIntaxAddition() {
        return declareIntaxAddition;
    }

    /**
     * 含税单价(申报)
     */
    public void setDeclareIntaxAddition(java.math.BigDecimal declareIntaxAddition) {
        this.declareIntaxAddition = declareIntaxAddition;
    }
    /**
     * 除税合价(申报)
     */
    public java.math.BigDecimal getDeclareExtaxAmount() {
        return declareExtaxAmount;
    }

    /**
     * 除税合价(申报)
     */
    public void setDeclareExtaxAmount(java.math.BigDecimal declareExtaxAmount) {
        this.declareExtaxAmount = declareExtaxAmount;
    }
    /**
     * 含税合价(申报)
     */
    public java.math.BigDecimal getDeclareIntaxAmount() {
        return declareIntaxAmount;
    }

    /**
     * 含税合价(申报)
     */
    public void setDeclareIntaxAmount(java.math.BigDecimal declareIntaxAmount) {
        this.declareIntaxAmount = declareIntaxAmount;
    }
    /**
     * 完成量(审核)
     */
    public java.math.BigDecimal getAuditCompleteNum() {
        return auditCompleteNum;
    }

    /**
     * 完成量(审核)
     */
    public void setAuditCompleteNum(java.math.BigDecimal auditCompleteNum) {
        this.auditCompleteNum = auditCompleteNum;
    }
    /**
     * 除税单价(审核)
     */
    public java.math.BigDecimal getAuditExtaxAddition() {
        return auditExtaxAddition;
    }

    /**
     * 除税单价(审核)
     */
    public void setAuditExtaxAddition(java.math.BigDecimal auditExtaxAddition) {
        this.auditExtaxAddition = auditExtaxAddition;
    }
    /**
     * 含税单价(审核)
     */
    public java.math.BigDecimal getAuditIntaxAddition() {
        return auditIntaxAddition;
    }

    /**
     * 含税单价(审核)
     */
    public void setAuditIntaxAddition(java.math.BigDecimal auditIntaxAddition) {
        this.auditIntaxAddition = auditIntaxAddition;
    }
    /**
     * 除税合价(审核)
     */
    public java.math.BigDecimal getAuditExtaxAmount() {
        return auditExtaxAmount;
    }

    /**
     * 除税合价(审核)
     */
    public void setAuditExtaxAmount(java.math.BigDecimal auditExtaxAmount) {
        this.auditExtaxAmount = auditExtaxAmount;
    }
    /**
     * 含税合价(审核)
     */
    public java.math.BigDecimal getAuditIntaxAmount() {
        return auditIntaxAmount;
    }

    /**
     * 含税合价(审核)
     */
    public void setAuditIntaxAmount(java.math.BigDecimal auditIntaxAmount) {
        this.auditIntaxAmount = auditIntaxAmount;
    }
    /**
     * 类别
     */
    public java.lang.String getCategorys() {
        return categorys;
    }

    /**
     * 类别
     */
    public void setCategorys(java.lang.String categorys) {
        this.categorys = categorys;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public BigDecimal getCumExtaxPrice() {
        return cumExtaxPrice;
    }

    public void setCumExtaxPrice(BigDecimal cumExtaxPrice) {
        this.cumExtaxPrice = cumExtaxPrice;
    }

    public BigDecimal getCumIntaxPrice() {
        return cumIntaxPrice;
    }

    public void setCumIntaxPrice(BigDecimal cumIntaxPrice) {
        this.cumIntaxPrice = cumIntaxPrice;
    }

    public BigDecimal getCurExtaxPrice() {
        return curExtaxPrice;
    }

    public void setCurExtaxPrice(BigDecimal curExtaxPrice) {
        this.curExtaxPrice = curExtaxPrice;
    }

    public BigDecimal getCurIntaxPrice() {
        return curIntaxPrice;
    }

    public void setCurIntaxPrice(BigDecimal curIntaxPrice) {
        this.curIntaxPrice = curIntaxPrice;
    }

    public BigDecimal getPastQuantity() {
        return pastQuantity;
    }

    public void setPastQuantity(BigDecimal pastQuantity) {
        this.pastQuantity = pastQuantity;
    }

    public String getIsEditState() {
        return isEditState;
    }

    public void setIsEditState(String isEditState) {
        this.isEditState = isEditState;
    }

    public BigDecimal getCumQuantity() {
        return cumQuantity;
    }

    public void setCumQuantity(BigDecimal cumQuantity) {
        this.cumQuantity = cumQuantity;
    }
}
